<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" />

<xsl:variable name="newline">
	<xsl:text>
	</xsl:text>
</xsl:variable>

<xsl:variable name="blankline">
	<xsl:text>
	
	</xsl:text>
</xsl:variable>

<xsl:template match="/">
	<html>
	<head>
		<xsl:call-template name="head" />
	</head>
	<body text="#330099">
		<h1>Statistics Department<br /><a id="thetop"/>
			<small>Courselist for <xsl:value-of select="/courselist/year" /></small>
		</h1>
		
<!-- 
insert topmatter and table only for complete listing
-->
		<xsl:if test="/courselist/showcourses = 'ALL' ">
			<xsl:call-template name="topmatter" />
			<!--  draw the table of courses at the top-->
			<center>
			<table width="90%" cellspacing="0" cellpadding="2" border="1"
				bordercolor="#000000">
				<tr>
					<th>Course</th>
					<th>Number</th>
<!--					<th>Level</th>-->
					<th>Instructor</th>
					<th>Time</th>
				</tr>
				<xsl:for-each select="/courselist/course">
					<xsl:sort select="semester" />
					<xsl:if test="id != ''">
						<xsl:call-template name="tableinfo" />
					</xsl:if>
				</xsl:for-each>
			</table>
			<br/>
			</center>
			<xsl:value-of select="$blankline" />		<!-- for readability of .html file,  -->
		</xsl:if>
		
<!--
detailed course listings
-->
		<dl>
			<xsl:choose>
				<xsl:when test="/courselist/showcourses = 'FALL' ">
					<h4> Courses taught in fall:</h4>
					<xsl:for-each select="/courselist/course[semester = 'FALL' or semester =
						'WHOLEYEAR']">
						<xsl:call-template name="courseinfo" />
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="/courselist/showcourses = 'SPRING' ">
					<h4> Courses taught in spring:</h4>
					<xsl:for-each select="/courselist/course[semester = 'SPRING' or semester
						= 'WHOLEYEAR']">
						<xsl:call-template name="courseinfo" />
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="/courselist/course">
						<xsl:call-template name="courseinfo" />
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</dl>
		<xsl:call-template name="endmatter" />
	</body>
	</html>
</xsl:template>
	
<!-- 
TEMPLATES
-->

	<!-- entries that go in top table-->
	<xsl:template name="tableinfo">
		<tr class="{semester}">
			<td style="font-size:14px" class="{semester}">
				<xsl:value-of select="./name" />
			</td>
			<td style="font-size:14px">
				<a href="#{id}">
					<xsl:value-of select="./id" />
				</a>
			</td>
<!--			<td style="font-size:14px">
				<xsl:value-of select="./level" />
			</td>
-->			<td style="font-size:14px">
				<xsl:value-of select="./instructor" />
			</td>
			<td style="font-size:14px">
				<xsl:value-of select="./time" />
			</td>
		</tr>
	</xsl:template>

	<!-- detailed course info -->
	<xsl:template name="courseinfo">
		<xsl:value-of select="$blankline" />		<!-- for readability of .html file,  -->
<!--		<div class="{semester}">-->
		<a id="{id}" />
		<dt style="font-weight: bold" class="{semester}"><xsl:value-of select="./name" /> (<xsl:value-of select="./number" />)
			</dt>
			<dd style="width:90%">
				<xsl:if test="instructor !=''">
					<i>Instructor: <xsl:value-of select="./instructor" /></i>
					<br />
				</xsl:if>
				<xsl:if test="time !=''">
					<i>Time: <xsl:value-of select="./time" /></i>
					<br />
				</xsl:if>
				<xsl:if test="classroom !=''">
					<i>Place: <xsl:value-of select="./classroom" /></i>
					<br />
				</xsl:if>
				<xsl:if test="webpage !=''">
					<i>Webpage: <a href="{webpage}">
							<xsl:value-of select="./webpage" />
						</a></i>
					<br />
				</xsl:if>
				<xsl:value-of select="./description" />
			</dd>
		<xsl:if test="/courselist/showcourses = 'ALL' ">
			<a href="#thetop">&#032;[back to top]</a>
		</xsl:if>
			<p />
	</xsl:template>

	<!-- style and head info  -->
	<xsl:template name="head">
		<title>Course list for Yale Statistics Department</title>
		<style>
		H1, H2 {color:#330099}
		a {color:#0066FF; text-decoration:none; font-weight:bold}
		a:hover {color:#FF0099}
		.xFALL{background-color:#996600}
		.FALL{background-color:#FF9966}
		.xSPRING{color:#339933}
		.SPRING{background-color:#66FF66}
		.WHOLEYEAR{color:#330099}
		.WHOLEYEAR{background-color:#FF99FF}
		.xXXX{color:#333333}
		.XXX{background-color:#CCCCCC}
		</style>
	</xsl:template>

	<!-- info at top of courselist -->
	<xsl:template name="topmatter">
		<ul>
			<li> 
				Organizational Meeting for all <xsl:value-of select="/courselist/semester" /> term
				courses whose times are not listed below: <b><xsl:value-of select="/courselist/org-meeting" /></b>. 
			</li>
			<li> 
				Those interested in attending one of the courses but unable to be present at this
				meeting should inform <a href="mailto:amy.mulholland@yale.edu">Amy Mulholland</a>
				beforehand and submit their schedules. </li>
			<li> 
				<div class="FALL"> Courses whose numbers end with <b>a</b> are offered in the FALL; </div> 
				<div class="SPRING"> courses whose numbers end with <b>b</b> are offered in the SPRING; </div> 
				<div class="WHOLEYEAR"> courses whose numbers end with <b>ab</b> are offered in both semesters. </div> 
			</li>
			<li> 
				Courses whose first or only number is 600 or above (such as Stat 600b/330b or Stat
				610a) are intended primarily for graduate students. If such a course does not have
				an undergraduate cross-listing, undergraduates need special permission to enroll. </li>
			<li>
				<a href="http://www.stat.yale.edu/Courses/classroomschedule.pdf">Schedule</a> of times
				when 24 Hillhouse Room 107 is in use. </li>
			<li>
				<a href="http://www.stat.yale.edu/Courses/oldcourses.html">Course lists for prior
				years</a>: These pages are not being updated; some of the links may no longer be
				working. </li>
			<li> 
				Director of Undergraduate Studies: <xsl:value-of select="/courselist/dus" />
			</li>
			<li> 
				Director of Graduate Studies: <xsl:value-of select="/courselist/dgs" />
			</li>
                        <li>
                                <a href="http://www.stat.yale.edu/~jay/GradFirstYear.html">Typical 1st-year courses</a> for Ph.D. and M.A. students.
                        </li>
		</ul>
	</xsl:template>

	<!-- show revision date -->
	<xsl:template name="endmatter">
		<hr align="left" width="30%" />
		<cite>Revised: <xsl:value-of select="/courselist/revised" /></cite>
	</xsl:template>

</xsl:stylesheet>
